@@ -6,7 +6,7 @@ let chorus count msg = for i = 1 to count do print_endline msg done
 
 (* Command line interface *)
 
-open Cmdliner;;
+open Cmdliner
 
 let count =
   let doc = "Repeat the message $(docv) times." in
@@ -22,7 +22,10 @@ let chorus_t = Term.(const chorus $ count $ msg)
 
 let info =
   let doc = "print a customizable message repeatedly" in
-  let man = [ `S "BUGS"; `P "Email bug reports to <hehey at example.org>.";] in
-  Term.info "chorus" ~version:"1.6.1" ~doc ~man
+  let man = [
+    `S Manpage.s_bugs;
+    `P "Email bug reports to <hehey at example.org>." ]
+  in
+  Term.info "chorus" ~version:"v1.0.2" ~doc ~exits:Term.default_exits ~man
 
-let () = match Term.eval (chorus_t, info)  with `Error _ -> exit 1 | _ -> exit 0
+let () = Term.exit @@ Term.eval (chorus_t, info)
