@@ -14,7 +14,7 @@ let cp verbose recurse force srcs dest =
 
 (* Command line interface *)
 
-open Cmdliner;;
+open Cmdliner
 
 let verbose =
   let doc = "Print file names as they are copied." in
@@ -35,18 +35,20 @@ let srcs =
 let dest =
   let doc = "Destination of the copy. Must be a directory if there is more
            than one $(i,SOURCE)." in
-  Arg.(required & pos ~rev:true 0 (some string) None & info [] ~docv:"DEST"
-         ~doc)
+  let docv = "DEST" in
+  Arg.(required & pos ~rev:true 0 (some string) None & info [] ~docv ~doc)
 
 let cmd =
   let doc = "copy files" in
-  let man = [
-    `S "BUGS";
-    `P "Email them to <hehey at example.org>.";
-    `S "SEE ALSO";
-    `P "$(b,mv)(1), $(b,scp)(1), $(b,umask)(2), $(b,symlink)(7)" ]
+  let man_xrefs =
+    [ `Tool "mv"; `Tool "scp"; `Page ("umask", 2); `Page ("symlink", 7) ]
+  in
+  let exits = Term.default_exits in
+  let man =
+    [ `S Manpage.s_bugs;
+      `P "Email them to <hehey at example.org>."; ]
   in
   Term.(ret (const cp $ verbose $ recurse $ force $ srcs $ dest)),
-  Term.info "cp" ~version:"1.6.1" ~doc ~man
+  Term.info "cp" ~version:"v1.0.2" ~doc ~exits ~man ~man_xrefs
 
-let () = match Term.eval cmd with `Error _ -> exit 1 | _ -> exit 0
+let () = Term.(exit @@ eval cmd)
